# Amplitude

Amplitude commands are used to create arbitrary time or frequency variations of load, displacement, and some interaction attributes throughout a step using step time or throughout an analysis using total time.

## Create amplitudes

### In Mdb

```{eval-rst}
.. autoclass:: abaqus.Amplitude.AmplitudeModel.AmplitudeModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

### In Odb

```{eval-rst}
.. autoclass:: abaqus.Amplitude.AmplitudeOdb.AmplitudeOdb
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### Amplitude

```{eval-rst}
.. autoclass:: abaqus.Amplitude.Amplitude.Amplitude
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ActuatorAmplitude

```{eval-rst}
.. autoclass:: abaqus.Amplitude.ActuatorAmplitude.ActuatorAmplitude
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BaselineCorrection

```{eval-rst}
.. autoclass:: abaqus.Amplitude.BaselineCorrection.BaselineCorrection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Correlation

```{eval-rst}
.. autoclass:: abaqus.Amplitude.Correlation.Correlation
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DecayAmplitude

```{eval-rst}
.. autoclass:: abaqus.Amplitude.DecayAmplitude.DecayAmplitude
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EquallySpacedAmplitude

```{eval-rst}
.. autoclass:: abaqus.Amplitude.EquallySpacedAmplitude.EquallySpacedAmplitude
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ModulatedAmplitude

```{eval-rst}
.. autoclass:: abaqus.Amplitude.ModulatedAmplitude.ModulatedAmplitude
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PeriodicAmplitude

```{eval-rst}
.. autoclass:: abaqus.Amplitude.PeriodicAmplitude.PeriodicAmplitude
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PsdDefinition

```{eval-rst}
.. autoclass:: abaqus.Amplitude.PsdDefinition.PsdDefinition
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SmoothStepAmplitude

```{eval-rst}
.. autoclass:: abaqus.Amplitude.SmoothStepAmplitude.SmoothStepAmplitude
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SolutionDependentAmplitude

```{eval-rst}
.. autoclass:: abaqus.Amplitude.SolutionDependentAmplitude.SolutionDependentAmplitude
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SpectrumAmplitude

```{eval-rst}
.. autoclass:: abaqus.Amplitude.SpectrumAmplitude.SpectrumAmplitude
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TabularAmplitude

```{eval-rst}
.. autoclass:: abaqus.Amplitude.TabularAmplitude.TabularAmplitude
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
